@@ -1,4 +1,4 @@
-/* $Id: loadavg.h,v 1.22 2003/10/19 16:10:17 carlos Exp $ */
+/* $Id: loadavg.h,v 1.27 2006/04/18 20:17:25 gpoo Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,7 +27,7 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_LOADAVG_LOADAVG		0
 #define GLIBTOP_LOADAVG_NR_RUNNING	1
@@ -40,14 +40,14 @@ typedef struct _glibtop_loadavg	glibtop_loadavg;
 
 struct _glibtop_loadavg
 {
-	u_int64_t flags;
+	guint64 flags;
 	double loadavg [3];		/* GLIBTOP_LOADAVG_LOADAVG	*/
-	u_int64_t nr_running,		/* GLIBTOP_LOADAVG_NR_RUNNING	*/
-		nr_tasks,		/* GLIBTOP_LOADAVG_NR_TASKS	*/
-		last_pid;		/* GLIBTOP_LOADAVG_LAST_PID	*/
+	guint64 nr_running;		/* GLIBTOP_LOADAVG_NR_RUNNING	*/
+	guint64 nr_tasks;		/* GLIBTOP_LOADAVG_NR_TASKS	*/
+	guint64 last_pid;		/* GLIBTOP_LOADAVG_LAST_PID	*/
 };
 
-#define glibtop_get_loadavg(loadavg)	glibtop_get_loadavg_l(glibtop_global_server, loadavg)
+void glibtop_get_loadavg(glibtop_loadavg *buf);
 
 #if GLIBTOP_SUID_LOADAVG
 #define glibtop_get_loadavg_r		glibtop_get_loadavg_p
@@ -65,17 +65,7 @@ void glibtop_init_loadavg_s (glibtop *server);
 void glibtop_get_loadavg_s (glibtop *server, glibtop_loadavg *buf);
 #endif
 
-#ifdef GLIBTOP_NAMES
 
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_loadavg [];
-extern const unsigned glibtop_types_loadavg [];
-extern const char *glibtop_labels_loadavg [];
-extern const char *glibtop_descriptions_loadavg [];
-
-#endif
-
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
