@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: proclist.h,v 1.32 2006/04/18 20:17:25 gpoo Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -29,10 +27,13 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-#include <glibtop/compat_10.h>
-#include <glibtop/array.h>
+G_BEGIN_DECLS
 
-BEGIN_LIBGTOP_DECLS
+#define GLIBTOP_PROCLIST_NUMBER	0
+#define GLIBTOP_PROCLIST_TOTAL	1
+#define GLIBTOP_PROCLIST_SIZE	2
+
+#define GLIBTOP_MAX_PROCLIST	3
 
 /* You can use the folowing constants as the `which' member of
  * glibtop_get_proclist () to specify which processes to fetch. */
@@ -44,7 +45,6 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_KERN_PROC_TTY		4
 #define GLIBTOP_KERN_PROC_UID		5
 #define GLIBTOP_KERN_PROC_RUID		6
-#define GLIBTOP_KERN_PROC_PPID		7
 
 #define GLIBTOP_KERN_PROC_MASK		15
 
@@ -52,7 +52,18 @@ BEGIN_LIBGTOP_DECLS
 #define GLIBTOP_EXCLUDE_SYSTEM		0x2000
 #define GLIBTOP_EXCLUDE_NOTTY		0x4000
 
-#define glibtop_get_proclist(array,which,arg) glibtop_get_proclist_l(glibtop_global_server, array, which, arg)
+typedef struct _glibtop_proclist	glibtop_proclist;
+
+struct _glibtop_proclist
+{
+	guint64	flags;
+	guint64 number;			/* GLIBTOP_PROCLIST_NUMBER	*/
+	guint64 total;			/* GLIBTOP_PROCLIST_TOTAL	*/
+	guint64 size;			/* GLIBTOP_PROCLIST_SIZE	*/
+};
+
+unsigned *
+glibtop_get_proclist(glibtop_proclist *buf, gint64 which, gint64 arg);
 
 #if GLIBTOP_SUID_PROCLIST
 #define glibtop_get_proclist_r		glibtop_get_proclist_p
@@ -61,34 +72,24 @@ BEGIN_LIBGTOP_DECLS
 #endif
 
 unsigned *
-glibtop_get_proclist_l (glibtop *server, glibtop_array *array,
-			int64_t which, int64_t arg);
+glibtop_get_proclist_l (glibtop *server, glibtop_proclist *buf,
+			gint64 which, gint64 arg);
 
 #if GLIBTOP_SUID_PROCLIST
-int glibtop_init_proclist_p (glibtop *server);
+void glibtop_init_proclist_p (glibtop *server);
 
 unsigned *
-glibtop_get_proclist_p (glibtop *server, glibtop_array *array,
-			int64_t which, int64_t arg);
+glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
+			gint64 which, gint64 arg);
 #else
-int glibtop_init_proclist_s (glibtop *server);
+void glibtop_init_proclist_s (glibtop *server);
 
 unsigned *
-glibtop_get_proclist_s (glibtop *server, glibtop_array *array,
-			int64_t which, int64_t arg);
+glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
+			gint64 which, gint64 arg);
 #endif
 
-#ifdef GLIBTOP_NAMES
 
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_proclist [];
-extern const unsigned glibtop_types_proclist [];
-extern const char *glibtop_labels_proclist [];
-extern const char *glibtop_descriptions_proclist [];
-
-#endif
-
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
