@@ -1,4 +1,4 @@
-/* $Id: procmap.h,v 1.16 2003/10/19 16:10:17 carlos Exp $ */
+/* $Id: procmap.h,v 1.23 2006/04/18 20:17:25 gpoo Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,7 +27,7 @@
 #include <glibtop.h>
 #include <glibtop/global.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define GLIBTOP_PROC_MAP_NUMBER		0
 #define GLIBTOP_PROC_MAP_TOTAL		1
@@ -35,15 +35,23 @@ BEGIN_LIBGTOP_DECLS
 
 #define GLIBTOP_MAX_PROC_MAP		3
 
-#define GLIBTOP_MAP_ENTRY_START		1
-#define GLIBTOP_MAP_ENTRY_END		2
-#define GLIBTOP_MAP_ENTRY_OFFSET	3
-#define GLIBTOP_MAP_ENTRY_PERM		4
-#define GLIBTOP_MAP_ENTRY_INODE		5
-#define GLIBTOP_MAP_ENTRY_DEVICE	6
-#define GLIBTOP_MAP_ENTRY_FILENAME	7
+#define GLIBTOP_MAP_ENTRY_START		0
+#define GLIBTOP_MAP_ENTRY_END		1
+#define GLIBTOP_MAP_ENTRY_OFFSET	2
+#define GLIBTOP_MAP_ENTRY_PERM		3
+#define GLIBTOP_MAP_ENTRY_INODE		4
+#define GLIBTOP_MAP_ENTRY_DEVICE	5
+#define GLIBTOP_MAP_ENTRY_FILENAME	6
 
-#define GLIBTOP_MAX_MAP_ENTRY		8
+/* Smap support */
+#define GLIBTOP_MAP_ENTRY_SIZE			 7
+#define GLIBTOP_MAP_ENTRY_RSS			 8
+#define GLIBTOP_MAP_ENTRY_SHARED_CLEAN		 9
+#define GLIBTOP_MAP_ENTRY_SHARED_DIRTY		10
+#define GLIBTOP_MAP_ENTRY_PRIVATE_CLEAN		11
+#define GLIBTOP_MAP_ENTRY_PRIVATE_DIRTY		12
+
+#define GLIBTOP_MAX_MAP_ENTRY		13
 
 #define GLIBTOP_MAP_FILENAME_LEN	215
 
@@ -59,19 +67,32 @@ typedef struct _glibtop_proc_map	glibtop_proc_map;
 
 struct _glibtop_map_entry
 {
-	u_int64_t flags, start, end, offset, perm, inode, device;
+	guint64 flags; 
+	guint64 start; 
+	guint64 end; 
+	guint64 offset; 
+	guint64 perm; 
+	guint64 inode; 
+	guint64 device;
+	guint64 size;
+	guint64 rss;
+	guint64 shared_clean; 
+	guint64 shared_dirty;
+	guint64 private_clean; 
+	guint64 private_dirty;
 	char filename [GLIBTOP_MAP_FILENAME_LEN+1];
 };
 
 struct _glibtop_proc_map
 {
-	u_int64_t	flags,
-		number,			/* GLIBTOP_PROC_MAP_NUMBER	*/
-		total,			/* GLIBTOP_PROC_MAP_TOTAL	*/
-		size;			/* GLIBTOP_PROC_MAP_SIZE	*/
+	guint64	flags;
+	guint64 number;			/* GLIBTOP_PROC_MAP_NUMBER	*/
+	guint64 total;			/* GLIBTOP_PROC_MAP_TOTAL	*/
+	guint64 size;			/* GLIBTOP_PROC_MAP_SIZE	*/
 };
+glibtop_map_entry *
+glibtop_get_proc_map(glibtop_proc_map *buf, pid_t pid);
 
-#define glibtop_get_proc_map(proc_map,pid) glibtop_get_proc_map_l(glibtop_global_server, proc_map, pid)
 
 #if GLIBTOP_SUID_PROC_MAP
 #define glibtop_get_proc_map_r		glibtop_get_proc_map_p
@@ -94,17 +115,7 @@ glibtop_map_entry *
 glibtop_get_proc_map_s (glibtop *server, glibtop_proc_map *buf, pid_t pid);
 #endif
 
-#ifdef GLIBTOP_NAMES
 
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_proc_map [];
-extern const unsigned glibtop_types_proc_map [];
-extern const char *glibtop_labels_proc_map [];
-extern const char *glibtop_descriptions_proc_map [];
-
-#endif
-
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
