@@ -1,4 +1,4 @@
-/* $Id: init.c,v 1.30 2003/10/20 15:19:41 hadess Exp $ */
+/* $Id: init.c,v 1.37 2005/12/12 09:38:08 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,15 +21,19 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
+#include <glibtop/error.h>
 #include <glibtop/sysdeps.h>
+#include <glibtop/open.h>
 #include <glibtop/parameter.h>
+#include <glibtop/init_hooks.h>
 
 #ifndef DEFAULT_PORT
 #define DEFAULT_PORT 42800
 #endif
 
-static glibtop _glibtop_global_server;
+static glibtop _glibtop_global_server = { 0 };
 glibtop *glibtop_global_server = &_glibtop_global_server;
 
 static void
@@ -50,7 +54,7 @@ _init_server (glibtop *server, const unsigned features)
 	if (server->server_rsh == NULL) {
 		const char *temp = getenv ("LIBGTOP_RSH") ?
 			getenv ("LIBGTOP_RSH") : "/usr/bin/ssh";
-		
+
 		server->server_rsh = g_strdup (temp);
 	}
 
@@ -78,15 +82,15 @@ _init_server (glibtop *server, const unsigned features)
 
 	/* If the first character of 'server_command' is a colon,
 	 * the first field is the method to connect to the server. */
-	
+
 	/* Everything up to the next colon is the method. */
-	
+
 	command = g_strdup (server->server_command+1);
 	temp = strstr (command, ":");
 	if (temp) *temp = 0;
-	
+
 	/* Dispatch method. */
-			
+
 	if (!strcmp (command, "direct")) {
 		/* Use sysdeps dir instead of connecting to server
 		 * even if using the server would be required on
@@ -106,16 +110,16 @@ _init_server (glibtop *server, const unsigned features)
 		} else {
 			char *temp2 = strstr (temp+1, ":");
 			if (temp2) *temp2 = 0;
-					
+
 			/* Override default. */
 			if (server->server_host)
 				g_free ((char *) server->server_host);
 
 			server->server_host = g_strdup (temp+1);
-					
+
 			temp = temp2;
 		}
-			
+
 		if (temp == NULL) {
 			/* If no value was set, we use DEFAULT_PORT. */
 			if (server->server_port == 0)
@@ -123,10 +127,10 @@ _init_server (glibtop *server, const unsigned features)
 		} else {
 			char *temp2 = strstr (temp+1, ":");
 			if (temp2) *temp2 = 0;
-					
+
 			if (sscanf (temp+1, "%ld", &server->server_port) != 1)
 				server->server_port = DEFAULT_PORT;
-					
+
 			temp = temp2 ? temp2 + 1 : temp2;
 		}
 
@@ -146,7 +150,7 @@ _init_server (glibtop *server, const unsigned features)
 				 server->server_command+1);
 
 	}
-			
+
 	g_free (command);
 }
 
@@ -173,27 +177,27 @@ glibtop_init_r (glibtop **server_ptr, unsigned long features, unsigned flags)
 	if ((server->flags & _GLIBTOP_INIT_STATE_INIT) == 0) {
 		if (flags & GLIBTOP_FEATURES_EXCEPT)
 			features = ~features & GLIBTOP_SYSDEPS_ALL;
-		
+
 		if (features == 0)
 			features = GLIBTOP_SYSDEPS_ALL;
-		
+
 		if (flags & GLIBTOP_FEATURES_NO_SERVER) {
 			server->method = GLIBTOP_METHOD_DIRECT;
 			features = 0;
 		}
-		
+
 		server->features = features;
-		
+
 		_init_server (server, features);
-		
+
 		server->flags |= _GLIBTOP_INIT_STATE_INIT;
-		
+
 		switch (server->method) {
 		case GLIBTOP_METHOD_PIPE:
 		case GLIBTOP_METHOD_UNIX:
 			if (glibtop_server_features & features)
 				break;
-			
+
 			server->method = GLIBTOP_METHOD_DIRECT;
 			break;
 		}
@@ -205,11 +209,11 @@ glibtop_init_r (glibtop **server_ptr, unsigned long features, unsigned flags)
 		return server;
 
 	/* Open server, but only if not already opened. */
-	
+
 	if ((server->flags & _GLIBTOP_INIT_STATE_OPEN) == 0)
 		glibtop_open_l (glibtop_global_server, "glibtop",
 				features, flags);
-	
+
 	return server;
 }
 
@@ -217,8 +221,8 @@ glibtop *
 glibtop_init_s (glibtop **server_ptr, unsigned long features, unsigned flags)
 {
 	glibtop *server;
-	glibtop_init_func_t *init_fkt;
-	
+	const glibtop_init_func_t *init_fkt;
+
 	if (server_ptr == NULL)
 		return NULL;
 
@@ -239,7 +243,7 @@ glibtop_init_s (glibtop **server_ptr, unsigned long features, unsigned flags)
 
 		for (init_fkt = _glibtop_init_hook_s; *init_fkt; init_fkt++)
 			(*init_fkt) (server);
-		
+
 		server->flags |= _GLIBTOP_INIT_STATE_SYSDEPS;
 	}
 
