@@ -1,4 +1,4 @@
-/* $Id: procmap.c,v 1.20 2003/10/19 16:55:32 carlos Exp $ */
+/* $Id: procmap.c,v 1.28 2005/12/12 09:38:11 jamesh Exp $ */
 
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
@@ -21,9 +21,9 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
-#include <glibtop/xmalloc.h>
 #include <glibtop/procmap.h>
 
 #include <glibtop_suid.h>
@@ -32,11 +32,29 @@
 #include <sys/param.h>
 #include <sys/proc.h>
 #include <sys/resource.h>
+#if defined(__NetBSD__) && (__NetBSD_Version__ < 105020000)
 #include <vm/vm_object.h>
 #include <vm/vm_prot.h>
 #include <vm/vm_map.h>
+#elif defined(__NetBSD__) && (__NetBSD_Version__ >= 105020000)
+#include <uvm/uvm_extern.h>
+#else
+#include <vm/vm_object.h>
+#include <vm/vm_map.h>
+#if (__FreeBSD_version >= 400011)
+#include <vm/vm.h>
+#else
+#include <vm/vm_prot.h>
+#endif
+#endif
 
+#ifdef __FreeBSD__
+#define _KVM_VNODE
+#endif
 #include <sys/vnode.h>
+#ifdef __FreeBSD__
+#undef _KVM_VNODE
+#endif
 #include <sys/mount.h>
 #include <ufs/ufs/quota.h>
 #include <ufs/ufs/inode.h>
@@ -46,7 +64,9 @@
 #include <sys/user.h>
 #endif
 #include <sys/sysctl.h>
+#if !defined(__NetBSD__) || (__NetBSD_Version__ < 105020000)
 #include <vm/vm.h>
+#endif
 
 #if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
 /* Fixme ... */
@@ -91,30 +111,37 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 	glibtop_map_entry *maps;
 #if defined __FreeBSD__
 	struct vnode vnode;
+#if __FreeBSD_version < 500039
 	struct inode inode;
-	struct mount mount;
+#endif
 #endif
 	int count, i = 0;
 	int update = 0;
 
 	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_PROC_MAP), 0);
-	
+
 	memset (buf, 0, sizeof (glibtop_proc_map));
 
 	/* It does not work for the swapper task. */
 	if (pid == 0) return NULL;
-	
+
 	glibtop_suid_enter (server);
 
 	/* Get the process data */
 	pinfo = kvm_getprocs (server->machine.kd, KERN_PROC_PID, pid, &count);
-	if ((pinfo == NULL) || (count < 1))
+	if ((pinfo == NULL) || (count < 1)) {
 		glibtop_error_io_r (server, "kvm_getprocs (%d)", pid);
+		return NULL;
+	}
 
 	/* Now we get the memory maps. */
 
 	if (kvm_read (server->machine.kd,
+#if defined(__FreeBSD__) && (__FreeBSD_version >= 500013)
+		      (unsigned long) pinfo [0].ki_vmspace,
+#else
 		      (unsigned long) pinfo [0].kp_proc.p_vmspace,
+#endif
 		      (char *) &vmspace, sizeof (vmspace)) != sizeof (vmspace))
 		glibtop_error_io_r (server, "kvm_read (vmspace)");
 
@@ -132,9 +159,7 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 
 	buf->total = buf->number * buf->size;
 
-	maps = glibtop_malloc_r (server, buf->total);
-
-	memset (maps, 0, buf->total);
+	maps = g_malloc0(buf->total);
 
 	buf->flags = _glibtop_sysdeps_proc_map;
 
@@ -214,9 +239,10 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 #endif
 
 #if defined(__NetBSD__) && (__NetBSD_Version__ >= 104000000)
+#if defined(UVM_VNODE_VALID)
 		if (!vnode.v_uvm.u_flags & UVM_VNODE_VALID)
 			continue;
-
+#endif
 		if ((vnode.v_type != VREG) || (vnode.v_tag != VT_UFS) ||
 		    !vnode.v_data) continue;
 
@@ -238,12 +264,23 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 
 		if (!object.handle)
 			continue;
-		
+
 		if (kvm_read (server->machine.kd,
 			      (unsigned long) object.handle,
 			      &vnode, sizeof (vnode)) != sizeof (vnode))
 			glibtop_error_io_r (server, "kvm_read (vnode)");
 
+#if defined(__FreeBSD__) && (__FreeBSD_version >= 500039)
+               switch (vnode.v_type) {
+                   case VREG:
+#if __FreeBSD_version < 600006
+                       maps [i-1].inode = vnode.v_cachedid;
+                       maps [i-1].device = vnode.v_cachedfs;
+#endif
+                   default:
+                   continue;
+               }
+#else
 		if ((vnode.v_type != VREG) || (vnode.v_tag != VT_UFS) ||
 		    !vnode.v_data) continue;
 
@@ -252,13 +289,9 @@ glibtop_get_proc_map_p (glibtop *server, glibtop_proc_map *buf,
 			      &inode, sizeof (inode)) != sizeof (inode))
 			glibtop_error_io_r (server, "kvm_read (inode)");
 
-		if (kvm_read (server->machine.kd,
-			      (unsigned long) vnode.v_mount,
-			      &mount, sizeof (mount)) != sizeof (mount))
-			glibtop_error_io_r (server, "kvm_read (mount)");
-
 		maps [i-1].inode  = inode.i_number;
 		maps [i-1].device = inode.i_dev;
+#endif
 #endif
 	} while (entry.next != first);
 
