@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: uptime.c,v 1.25 2005/07/23 00:01:11 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,54 +25,41 @@
 #include <glibtop/error.h>
 #include <glibtop/uptime.h>
 
-static unsigned long _glibtop_sysdeps_uptime =
-(1L << GLIBTOP_UPTIME_UPTIME) + (1L << GLIBTOP_UPTIME_IDLETIME);
+#include "glibtop_private.h"
+
+#include <time.h>
+
+static const unsigned long _glibtop_sysdeps_uptime =
+  (1UL << GLIBTOP_UPTIME_UPTIME) \
++ (1UL << GLIBTOP_UPTIME_IDLETIME) \
++ (1UL << GLIBTOP_UPTIME_BOOT_TIME);
 
 /* Init function. */
 
-int
+void
 glibtop_init_uptime_s (glibtop *server)
 {
-    server->sysdeps.uptime = _glibtop_sysdeps_uptime;
-
-    return 0;
+	server->sysdeps.uptime = _glibtop_sysdeps_uptime;
 }
 
 /* Provides uptime and idle time. */
 
 #define FILENAME	"/proc/uptime"
 
-int
+void
 glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
 {
-    char buffer [BUFSIZ], *p;
-    int fd, len;
+	char buffer [BUFSIZ], *p;
 
-    glibtop_init_s (&server, GLIBTOP_SYSDEPS_UPTIME, 0);
+	glibtop_init_s (&server, GLIBTOP_SYSDEPS_UPTIME, 0);
 
-    memset (buf, 0, sizeof (glibtop_uptime));
+	memset (buf, 0, sizeof (glibtop_uptime));
 
-    fd = open (FILENAME, O_RDONLY);
-    if (fd < 0) {
-	glibtop_warn_io_r (server, "open (%s)", FILENAME);
-	return -1;
-    }
+	file_to_buffer(server, buffer, FILENAME);
 
-    len = read (fd, buffer, BUFSIZ-1);
-    if (len < 0) {
-	close (fd);
-	glibtop_warn_io_r (server, "read (%s)", FILENAME);
-	return -1;
-    }
+	buf->uptime   = g_ascii_strtod (buffer, &p);
+	buf->idletime = g_ascii_strtod (p, &p);
+	buf->boot_time = get_boot_time(server);
 
-    close (fd);
-
-    buffer [len] = '\0';
-
-    buf->uptime   = strtod (buffer, &p);
-    buf->idletime = strtod (p, &p);
-
-    buf->flags = _glibtop_sysdeps_uptime;
-
-    return 0;
+	buf->flags = _glibtop_sysdeps_uptime;
 }
