@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: uptime.c,v 1.16 2005/12/12 09:38:12 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,45 +21,41 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/uptime.h>
 
 #include <time.h>
 
-static unsigned long _glibtop_sysdeps_uptime =
+static const unsigned long _glibtop_sysdeps_uptime =
 (1L << GLIBTOP_UPTIME_UPTIME);
 
 /* Init function. */
 
-int
+void
 glibtop_init_uptime_s (glibtop *server)
 {
-    server->sysdeps.uptime = _glibtop_sysdeps_uptime;
-
-    return 0;
+	server->sysdeps.uptime = _glibtop_sysdeps_uptime;
 }
 
 /* Provides uptime and idle time. */
 
-int
+void
 glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
 {
-    struct tbl_sysinfo sysinfo;
-    int ret;
-	
-    glibtop_init_s (&server, GLIBTOP_SYSDEPS_UPTIME, 0);
+	struct tbl_sysinfo sysinfo;
 
-    memset (buf, 0, sizeof (glibtop_uptime));
-	
-    ret = table (TBL_SYSINFO, 0, (char *) &sysinfo, 1,
-		 sizeof (struct tbl_sysinfo)); 
+	glibtop_init_s (&server, GLIBTOP_SYSDEPS_UPTIME, 0);
 
-    if (ret != 1) return -1;
-		
-    buf->uptime = (double) (time (NULL) - sysinfo.si_boottime);
+	memset (buf, 0, sizeof (glibtop_uptime));
 
-    buf->flags = _glibtop_sysdeps_uptime;
+	if(table (TBL_SYSINFO, 0, (char *) &sysinfo, 1,
+		   sizeof (struct tbl_sysinfo)) != 1)
+	  return;
 
-    return 0;
+	buf->uptime = (double) (time (NULL) - sysinfo.si_boottime);
+	buf->boot_time = sysinfo.si_boottime;
+
+	buf->flags = _glibtop_sysdeps_uptime;
 }
