@@ -1,4 +1,4 @@
-/* $Id: open.c,v 1.21 2003/10/19 16:55:46 carlos Exp $ */
+/* $Id: open.c,v 1.25 2006/06/24 17:39:49 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,8 +21,10 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop/open.h>
 #include <glibtop/cpu.h>
+#include <glibtop/error.h>
 
 #include <unistd.h>
 #include <dlfcn.h>
@@ -44,19 +46,21 @@ glibtop_get_kstats(glibtop *server)
     kstat_t *ksp;
     int nproc_same, new_ncpu;
 
-    new_ncpu = sysconf(_SC_NPROCESSORS_CONF);
+    server->ncpu = new_ncpu = sysconf(_SC_NPROCESSORS_CONF);
+
 
     if(!kc)
     {
-        server->ncpu = new_ncpu;
-        server->machine.vminfo_kstat = NULL;
-        server->machine.system = NULL;
-        server->machine.syspages = NULL;
-        server->machine.bunyip = NULL;
-        return;
+	server->ncpu = new_ncpu;
+	server->machine.vminfo_kstat = NULL;
+	server->machine.system = NULL;
+	server->machine.syspages = NULL;
+	server->machine.bunyip = NULL;
+	return;
     }
 
     do {
+
 	ksp = kstat_lookup(kc, "unix", -1, "vminfo");
 	server->machine.vminfo_kstat = ksp;
 	if(ksp)
@@ -64,7 +68,7 @@ glibtop_get_kstats(glibtop *server)
 	    kstat_read(kc, ksp, &server->machine.vminfo);
 	    /* Don't change snaptime if we only need to reinitialize kstats */
 	    if(!(server->machine.vminfo_snaptime))
-	        server->machine.vminfo_snaptime = ksp->ks_snaptime;
+		server->machine.vminfo_snaptime = ksp->ks_snaptime;
 	}
 
 	/* We don't know why was kstat chain invalidated. It could have
@@ -79,7 +83,8 @@ glibtop_get_kstats(glibtop *server)
 	    char cpu[20];
 
 	    for(i = 0, checked = 0; i < GLIBTOP_NCPU || checked == new_ncpu; ++i)
-		if(server->machine.cpu_stat_kstat[i])
+                if(!server->machine.cpu_stat_kstat[i])
+
 		{
 		    sprintf(cpu, "cpu_stat%d", i);
 		    if(!(server->machine.cpu_stat_kstat[i] =
@@ -91,15 +96,15 @@ glibtop_get_kstats(glibtop *server)
 		    ++checked;
 		}
 	}
+
 	if(!nproc_same)
 	{
 	    processorid_t p;
 	    int found;
 	    char cpu[20];
 
-	    if(new_ncpu > GLIBTOP_NCPU)
-		new_ncpu = GLIBTOP_NCPU;
-	    server->ncpu = new_ncpu;
+	    server->ncpu = new_ncpu = MIN(new_ncpu, GLIBTOP_NCPU);
+
 	    for(p = 0, found = 0; p < GLIBTOP_NCPU && found != new_ncpu; ++p)
 	    {
 		if(p_online(p, P_STATUS) < 0)
@@ -141,6 +146,8 @@ glibtop_open_s (glibtop *server, const char *program_name,
     for(i = 0; page; ++i, page >>= 1);
     server->machine.pagesize = i - 1;
     server->machine.ticks = sysconf(_SC_CLK_TCK);
+    if(server->machine.kc)
+    	kstat_close(server->machine.kc);
     server->machine.kc = kc = kstat_open ();
 
 #if 0
@@ -183,14 +190,14 @@ glibtop_open_s (glibtop *server, const char *program_name,
 	    switch(kn->data_type)
 	    {
 #ifdef KSTAT_DATA_INT32
-	        case KSTAT_DATA_INT32:  server->machine.boot = kn->value.i32;
-				        break;
-	        case KSTAT_DATA_UINT32: server->machine.boot = kn->value.ui32;
-				        break;
-	        case KSTAT_DATA_INT64:  server->machine.boot = kn->value.i64;
-				        break;
-	        case KSTAT_DATA_UINT64: server->machine.boot = kn->value.ui64;
-				        break;
+		case KSTAT_DATA_INT32:  server->machine.boot = kn->value.i32;
+					break;
+		case KSTAT_DATA_UINT32: server->machine.boot = kn->value.ui32;
+					break;
+		case KSTAT_DATA_INT64:  server->machine.boot = kn->value.i64;
+					break;
+		case KSTAT_DATA_UINT64: server->machine.boot = kn->value.ui64;
+					break;
 #else
 		case KSTAT_DATA_LONG:      server->machine.boot = kn->value.l;
 					   break;
@@ -206,9 +213,11 @@ glibtop_open_s (glibtop *server, const char *program_name,
 
     /* Now let's have a bit of magic dust... */
 
-#if GLIBTOP_SOLARIS_RELEASE >= 560
+#if GLIBTOP_SOLARIS_RELEASE >= 50600
 
     dl = dlopen("/usr/lib/libproc.so", RTLD_LAZY);
+    if(server->machine.libproc)
+    	dlclose(server->machine.libproc);
     server->machine.libproc = dl;
     if(dl)
     {
@@ -218,10 +227,11 @@ glibtop_open_s (glibtop *server, const char *program_name,
        if(!func)
 	  func = dlsym(dl, "proc_objname");	/* Solaris 7 */
        server->machine.objname = (void (*)
-	     			 (void *, uintptr_t, const char *, size_t))func;
+				 (void *, uintptr_t, const char *, size_t))func;
        server->machine.pgrab = (struct ps_prochandle *(*)(pid_t, int, int *))
 	  		       dlsym(dl, "Pgrab");
        server->machine.pfree = (void (*)(void *))dlsym(dl, "Pfree");
+       
     }
     else
     {
