@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: procmem.c,v 1.15 2005/12/12 09:38:14 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/procmem.h>
 
@@ -30,21 +29,17 @@ static const unsigned long _glibtop_sysdeps_proc_mem = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_proc_mem_s (glibtop *server)
 {
-    server->sysdeps.proc_mem = _glibtop_sysdeps_proc_mem;
-
-    return 0;
+	server->sysdeps.proc_mem = _glibtop_sysdeps_proc_mem;
 }
 
 /* Provides detailed information about a process. */
 
-int
+void
 glibtop_get_proc_mem_s (glibtop *server, glibtop_proc_mem *buf,
 			pid_t pid)
 {
-    memset (buf, 0, sizeof (glibtop_proc_mem));
-
-    return 0;
+	memset (buf, 0, sizeof (glibtop_proc_mem));
 }
