@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: proclist.c,v 1.12 2005/12/12 09:38:14 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/proclist.h>
@@ -33,21 +32,19 @@ static const unsigned long _glibtop_sysdeps_proclist = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_proclist_p (glibtop *server)
 {
-    server->sysdeps.proclist = _glibtop_sysdeps_proclist;
-
-    return 0;
+	server->sysdeps.proclist = _glibtop_sysdeps_proclist;
 }
 
 unsigned *
 glibtop_get_proclist_p (glibtop *server, glibtop_proclist *buf,
-			int64_t which, int64_t arg)
+			gint64 which, gint64 arg)
 {
-    glibtop_init_p (server, GLIBTOP_SYSDEPS_PROCLIST, 0);
-	
-    memset (buf, 0, sizeof (glibtop_proclist));
+	glibtop_init_p (server, GLIBTOP_SYSDEPS_PROCLIST, 0);
 
-    return NULL;
+	memset (buf, 0, sizeof (glibtop_proclist));
+
+	return NULL;
 }
