@@ -1,4 +1,4 @@
-/* $Id: procmap.c,v 1.2 1999/02/23 11:46:57 martin Exp $ */
+/* $Id: procmap.c,v 1.9 2005/12/12 09:38:14 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,9 +21,9 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
-#include <glibtop/xmalloc.h>
 #include <glibtop/procmap.h>
 
 static const unsigned long _glibtop_sysdeps_proc_map = 0;
